@@ -536,6 +536,16 @@ def push(
         raise_error("DVC push failed")
 
 
+@app.command(name="sync")
+def sync(
+    no_check_auth: Annotated[bool, typer.Option("--no-check-auth")] = False,
+):
+    """Sync the project repo by pulling and then pushing."""
+    # TODO: Walk users through merge conflicts if they arise
+    pull(no_check_auth=no_check_auth)
+    push(no_check_auth=no_check_auth)
+
+
 @app.command(name="ignore")
 def ignore(
     path: Annotated[str, typer.Argument(help="Path to ignore.")],
@@ -846,6 +856,8 @@ def run_in_env(
         ]
         if platform:
             docker_cmd += ["--platform", platform]
+        if docker_user := env.get("user"):
+            docker_cmd += ["--user", docker_user]
         docker_cmd += env.get("args", [])
         docker_cmd += [
             "-it" if sys.stdin.isatty() else "-i",
